datadog\_api\_client
====================

.. toctree::
   :maxdepth: 4

   datadog_api_client.v1
   datadog_api_client.v2


api\_client
-----------

.. automodule:: datadog_api_client.api_client
   :members:
   :show-inheritance:

configuration
-------------

.. automodule:: datadog_api_client.configuration
   :members:
   :show-inheritance:

exceptions
----------

.. automodule:: datadog_api_client.exceptions
   :members:
   :show-inheritance:

model\_utils
------------

.. automodule:: datadog_api_client.model_utils
   :members:
   :show-inheritance:

rest
----

.. automodule:: datadog_api_client.rest
   :members:
   :show-inheritance:


.. automodule:: datadog_api_client
   :members:
   :show-inheritance:
